@@ -1,6 +1,6 @@
 //! # Me Responses
 pub mod me;
-pub use me::{Friend, MeData};
+pub use me::{Friend, MeData, Saved, SavedData};
 
 pub mod inbox;
 pub use inbox::{Inbox, InboxData};
